/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.tools.util;

import java.io.StringReader;

import org.xml.sax.InputSource;

public final class JAXBUtils {

    private static final String SCHEMA =
        "<schema xmlns=\"http://www.w3.org/2001/XMLSchema\""
        + " xmlns:jaxb=\"http://java.sun.com/xml/ns/jaxb\" jaxb:version=\"2.0\""
        + " targetNamespace=\"${targetNamespace}\">"
        + " <annotation>"
        + "  <appinfo>"
        + "   <jaxb:schemaBindings>"
        + "    <jaxb:package name=\"${package}\" />"
        + "   </jaxb:schemaBindings>"
        + "  </appinfo>"
        + " </annotation>"
        + "</schema>";

    private JAXBUtils() {
    }

    /**
     * Create the jaxb binding to customize namespace to package mapping
     *
     * @param namespace
     * @param pkgName
     * @return InputSource
     */
    public static InputSource getPackageMappingSchemaBinding(String namespace, String pkgName) {
        final InputSource is = new InputSource(
            new StringReader(SCHEMA.replace("${targetNamespace}", namespace).replace("${package}", pkgName)));
        is.setSystemId(namespace);
        return is;
    }
}
